# Generated by Django 4.1.6 on 2023-02-18 19:41

from django.db import migrations, models
import taggit.managers
import utilities.json


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('extras', '0084_staging'),
        ('ipam', '0063_standardize_description_comments'),
    ]

    operations = [
        migrations.CreateModel(
            name='VLANGroupSet',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True, null=True)),
                ('last_updated', models.DateTimeField(auto_now=True, null=True)),
                ('custom_field_data', models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder)),
                ('name', models.CharField(max_length=100, unique=True)),
                ('description', models.CharField(blank=True, max_length=200)),
                ('comments', models.TextField(blank=True)),
                ('tags', taggit.managers.TaggableManager(through='extras.TaggedItem', to='extras.Tag')),
                ('vlan_groups', models.ManyToManyField(blank=True, related_name='vlan_group_sets', to='ipam.vlangroup')),
            ],
            options={
                'ordering': ('name',),
            },
        ),
    ]
